# -*- coding: utf-8 -*-

"""
camplight
~~~~~~~~~

Python implementation of Campfire API

"""

__author__ = 'Mathias Lafeldt <mathias.lafeldt@gmail.com>'
__license__ = 'MIT'
__version__ = '0.9.1'

from .api import *
from .exceptions import *
